@@ -1,9 +1,11 @@
 /*
+ * Copyright © 2007, 2008  Ryan Lortie
  * Copyright © 2009 Codethink Limited
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of version 3 of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1
+ * of the licence, or (at your option) any later version.
  *
  * See the included COPYING file for more information.
  *
@@ -36,7 +38,7 @@ dconf_writer_allocate (DConfWriter *writer,
                        gsize        size,
                        guint32     *index)
 {
-  struct chunk_header *chunk = (gpointer) (writer->data.blocks + 
+  struct chunk_header *chunk = (gpointer) (writer->data.blocks +
                                            writer->data.super->next);
 
   if (!dconf_writer_in_bounds (writer, chunk, &chunk->contents[size]))
@@ -248,6 +250,37 @@ dconf_writer_set (DConfWriter  *writer,
   return dconf_writer_merge (writer, key, &empty_string, &value, 1);
 }
 
+gboolean
+dconf_writer_check_set (const gchar  *key,
+                        GError      **error)
+{
+  gint i;
+
+  if (key[0] != '/')
+    {
+      g_set_error (error, 0, 0,
+                   "key must start with a slash");
+      return FALSE;
+    }
+
+  for (i = 1; key[i]; i++)
+    if (key[i] == '/' && key[i - 1] == '/')
+      {
+        g_set_error (error, 0, 0,
+                     "key must not contain two adjacent slashes");
+        return FALSE;
+      }
+
+  if (key[i - 1] == '/')
+    {
+      g_set_error (error, 0, 0,
+                   "key must not end with a slash");
+      return FALSE;
+    }
+
+  return TRUE;
+}
+
 GVariant *
 dconf_writer_get_entry_value (DConfWriter                     *writer,
                               const volatile struct dir_entry *entry)
